# Dividers

Creating dividers (divs) for CLI or output files

## Created with Python
![Static Badge](https://img.shields.io/badge/Python-3.12-Green?style=flat-square&link=https%3A%2F%2Fwww.python.org%2F)

### Usage:
```python
import div

div = div.div('=', 100)

print(div)
print(div.div('-', 30))
```